import requests
from bs4 import BeautifulSoup
import time
import re
from v3_filter import filterv2
from v3_elasticId_gen import elasticId
import datetime
import pytz
import traceback
from v3_proxies import proxies



def elastic_data_dict(eachLink):
    skipList = ['/showbiz/','/travel/','/entertainment/','/life-style/','/pictures/','/videos/']
    if any(word in eachLink for word in skipList):
        return False

    headers = {
            'dnt': "1",
            'upgrade-insecure-requests': "1",
            'user-agent': "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.111 Safari/537.36",
            'accept': "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
            'cache-control': "no-cache"
                }

    try:
        page = requests.get(eachLink)
    except requests.exceptions.TooManyRedirects:
        return False
    page = requests.get(eachLink,headers=headers) 
    if page.status_code in [403,500,502]:
        page = proxies.try_proxy(eachLink,headers)
    if page.status_code in [404]:
        return False 
    with open(f'express.txt','wb') as f:
        f.write((eachLink+'\n').encode('utf-8'))
        f.write(page.content) 
    soup = BeautifulSoup(page.content, 'html5lib')
    ids = eachLink.split('/')[-2]
    headline = soup.find('h1').text    
    article = soup.find('h3').text
    authors = soup.find('span', itemprop = 'author').text if soup.find('span', itemprop = 'author') else ''
    timeStamp = soup.find('meta',itemprop = 'datepublished')['content']
    text_list = soup.find_all('div', class_ = 'text-description')
    for text in text_list:
        paras = text.find_all(['p','li'])
        for tag in paras:
            if re.search('READ MORE|DON\'T MISS|DONT MISS', str(tag), re.IGNORECASE) or 'If you\'ve been affected by this issue' in str(tag):
                tag.decompose()
        article = article + ' ' + (' '.join([p.text for p in paras]))

    tags = soup.find('div', class_ = 'clearfix related_entities tags-element')
    if tags is not None:
        source_tags = [tag.text for tag in tags.find_all('a')]

    timeStamp = datetime.datetime.strptime(timeStamp+'+0000', '%Y-%m-%dT%H:%M:%SZ%z')
    timeStamp = int(timeStamp.astimezone(pytz.timezone("UTC")).timestamp())

    ids_hash = elasticId.generate(ids)

    try:
        ret = filterv2.filter(article)
    except:
        print(eachLink)
        raise Exception(traceback.format_exc())
    if ret == False:
        return False
    data_dict = {
          'headline': headline,
          'main_article': article,
          'published_timestamp': timeStamp,
          'source_url': eachLink,
          'source': "Daily Express",
          'ISIN': "NULL",
          'sector': ret['sector_list'],
          'category': "NULL",
          'author': authors,
          'stock_symbol': "NULL",
          'debt_listing': ret['debt_listing_list'],
          'id_on_source': ids,
          'sentiment': 'NULL',
          'industry': ret['industry_list'],
          'company_name': ret['company_list'],
          'source_language': "English",
          'entity_id': ret['entity_id_list'],
          'tags': ret['tags'],
          'tags_common': ret['tags_common'],
          'article_desc': '',
          'r': ret['r'],
          'n': ret['n'],
          'ns':ret['ns'],
          'nss': ret['nss'],
          'ta': ret['ta'],
          'country': ret['country'],
          'usd_sales': ret['usd_sales']
        }

    if(len(data_dict["main_article"])>260):
        loc=data_dict["main_article"].find(' ',250,260)
        if(loc!=-1):
            data_dict['article_desc']=data_dict["main_article"][0:loc]
        else:
            data_dict['article_desc']=data_dict["main_article"][0:250]
    else:
        data_dict['article_desc']=data_dict["main_article"]

    return data_dict, ids_hash


print(elastic_data_dict('https://www.express.co.uk/news/royal/1358314/Queen-news-Meghan-Markle-Prince-Harry-Remembrance-Sunday-wreath-LA-latest-vn'))