import requests
from bs4 import BeautifulSoup
import time
import re
from v3_filter import filterv2
from v3_elasticId_gen import elasticId
import datetime
import pytz
import traceback
from v3_proxies import proxies


def elastic_data_dict(eachLink):
    skipList = ['/tvandshowbiz/','/sport/','/dream-team/','/travel/','/tv/','/video/','/fabulous/']
    if any(word in eachLink for word in skipList):
        return False

    
    headers={
            "accept":"*/*",
            "accept-encoding":"gzip, deflate, br",
            "accept-language":"en-GB,en-US;q=0.9,en;q=0.8",
            "cache-control": "no-cache",
            "sec-fetch-dest": "script",
            "sec-fetch-mode": "no-cors",
            "sec-fetch-site": "cross-site",
            "user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/86.0.4240.111 Safari/537.36"
    }

    page = requests.get(eachLink, headers = headers)
    if page.status_code in [403,500,502]:
        page = proxies.try_proxy(eachLink,headers)
    if page.status_code in [404]:
        return False   
    
    with open(f'thesun.txt','wb') as f:
        f.write((eachLink+'\n').encode('utf-8'))
        f.write(page.content)
    soup = BeautifulSoup(page.content, 'html5lib')
    ids = eachLink.split('/')[-3]
    headline = soup.find('h1', class_ = 'article__headline').text
    article = ''
    authors = soup.find('li', class_ = 'article__author-list t-p-background-color__before').text if soup.find('li', class_ = 'article__author-list t-p-background-color__before') else ''
    timeStamp = soup.find('span', class_ = 'article__datestamp').text + soup.find('span', class_ = 'article__timestamp').text
    text_list = soup.find('div', class_ = 'article__content').find_all(['p', 'li','h2'])
    
    for para in text_list:
        article = article + ' ' + para.text
                
    tags = soup.find_all('li', class_ = 'tags__item t-p-background-color__after')
    if tags != []:
        source_tags = ', '.join([tag.text for tag in tags])
    else:
        source_tags = ''

    timeStamp = datetime.datetime.strptime(timeStamp+' +0000', '%d %b %Y, %H:%M %z')
    timeStamp = int(timeStamp.astimezone(pytz.timezone('UTC')).timestamp())

    ids_hash = elasticId.generate(ids)

    try:
        ret = filterv2.filter(article)
    except:
        print(eachLink)
        raise Exception(traceback.format_exc())
    if ret == False:
        return False
    data_dict = {
          'headline': headline,
          'main_article': article,
          'published_timestamp': timeStamp,
          'source_url': eachLink,
          'source': 'The Sun',
          'ISIN': "NULL",
          'sector': ret['sector_list'],
          'category': "NULL",
          'author': authors,
          'stock_symbol': "NULL",
          'debt_listing': ret['debt_listing_list'],
          'id_on_source': ids,
          'sentiment': 'NULL',
          'industry': ret['industry_list'],
          'company_name': ret['company_list'],
          'source_language': "English",
          'entity_id': ret['entity_id_list'],
          'tags': ret['tags'],
          'tags_common': ret['tags_common'],
          'article_desc': '',
          'r': ret['r'],
          'n': ret['n'],
          'ns':ret['ns'],
          'nss': ret['nss'],
          'ta': ret['ta'],
          'country': ret['country'],
          'usd_sales': ret['usd_sales'],
          'source_categories': source_tags
        }

    if(len(data_dict["main_article"])>260):
        loc=data_dict["main_article"].find(' ',250,260)
        if(loc!=-1):
            data_dict['article_desc']=data_dict["main_article"][0:loc]
        else:
            data_dict['article_desc']=data_dict["main_article"][0:250]
    else:
        data_dict['article_desc']=data_dict["main_article"]

    return data_dict, ids_hash

